public inbox for igt-dev@lists.freedesktop.org
 help / color / mirror / Atom feed
* [PATCH i-g-t v2 1/1] tests/kms_color: Add 10-bit color depth support to gamma test for MediaTek
@ 2026-04-13  1:41 Jay Liu
  2026-04-13  6:50 ` Jani Nikula
  0 siblings, 1 reply; 3+ messages in thread
From: Jay Liu @ 2026-04-13  1:41 UTC (permalink / raw)
  To: igt-dev
  Cc: Jason-JH Lin, Paul-PL Chen, Nancy Lin, Singo Chang, Gil Dekel,
	Yacoub, Sharma Swati2, Project_Global_Chrome_Upstream_Group,
	Jay Liu

1. Add 10-bit color depth flow to gamma test for MediaTek devices, which only
support bit-true results with 10-bit data. The test now selects 8-bit or
10-bit color depth and framebuffer format based on device type.

2. To satisfy the legacy gamma test requirements, the MTK Gamma LUT limit
should be set to 4092, in the current 16-bit LUT design, setting the entry
 to 0xffd0 ensures the driver maps it correctly to 4092.

Signed-off-by: Jay Liu <jay.liu@mediatek.com>
---
 tests/kms_color.c | 35 +++++++++++++++++++++++++++--------
 1 file changed, 27 insertions(+), 8 deletions(-)

diff --git a/tests/kms_color.c b/tests/kms_color.c
index 565edb2dc..033207368 100644
--- a/tests/kms_color.c
+++ b/tests/kms_color.c
@@ -288,7 +288,7 @@ static bool test_pipe_legacy_gamma(data_t *data,
 	fb_id = igt_create_fb(data->drm_fd,
 			      mode->hdisplay,
 			      mode->vdisplay,
-			      DRM_FORMAT_XRGB8888,
+			      data->drm_format,
 			      DRM_FORMAT_MOD_LINEAR,
 			      &fb);
 	igt_assert(fb_id);
@@ -296,7 +296,7 @@ static bool test_pipe_legacy_gamma(data_t *data,
 	fb_modeset_id = igt_create_fb(data->drm_fd,
 				      mode->hdisplay,
 				      mode->vdisplay,
-				      DRM_FORMAT_XRGB8888,
+				      data->drm_format,
 				      DRM_FORMAT_MOD_LINEAR,
 				      &fb_modeset);
 	igt_assert(fb_modeset_id);
@@ -322,9 +322,20 @@ static bool test_pipe_legacy_gamma(data_t *data,
 	igt_plane_set_fb(primary, &fb);
 
 	red_lut[0] = green_lut[0] = blue_lut[0] = 0;
-	for (i = 1; i < legacy_lut_size; i++)
-		red_lut[i] = green_lut[i] = blue_lut[i] = 0xffff;
-	igt_assert_eq(drmModeCrtcSetGamma(data->drm_fd, primary->crtc->crtc_id,
+	for (i = 1; i < legacy_lut_size; i++) {
+		/*
+		 * The Medaitek Gamma LUT maps 10bit input data to 12bit output.
+		 * In this test case, the maximum input value is 1023.
+		 * When the Gamma function is disabled, the data defaults to a 4092 output.
+		 * To achieve bit true results, the Gamma LUT maximum must be set to 4092.
+		 * Note that 0xFFFD0 represents 16-bit,which maps to 4092 in 12-bit depth.
+		 */
+		if (is_mtk_device(data->drm_fd))
+			red_lut[i] = green_lut[i] = blue_lut[i] = 0xffd0;
+		else
+			red_lut[i] = green_lut[i] = blue_lut[i] = 0xffff;
+	}
+	igt_assert_eq(drmModeCrtcSetGamma(data->drm_fd, primary->pipe->crtc_id,
 					  legacy_lut_size, red_lut, green_lut, blue_lut), 0);
 	igt_display_commit(&data->display);
 	igt_wait_for_vblank(primary->crtc);
@@ -752,14 +763,22 @@ static void
 run_gamma_degamma_tests_for_crtc(data_t *data, igt_crtc_t *crtc,
 				 bool (*test_t)(data_t*, igt_plane_t*))
 {
+	bool is_mtk = false;
+
 	test_setup(data, crtc);
 
+	/* MediaTek requires 10-bit pipeline for accurate (bit true) color processing */
+	if (is_mtk_device(data->drm_fd))
+		is_mtk = true;
+
 	/*
 	 * We assume an 8bits depth per color for degamma/gamma LUTs
 	 * for CRC checks with framebuffer references.
 	 */
-	data->color_depth = 8;
-	data->drm_format = DRM_FORMAT_XRGB8888;
+
+	/* MediaTek requires 10-bit pipeline for accurate (bit true) color processing */
+	data->color_depth = is_mtk ? 10 : 8;
+	data->drm_format = is_mtk ? DRM_FORMAT_XRGB2101010 : DRM_FORMAT_XRGB8888;
 	data->mode = igt_output_get_mode(data->output);
 
 	igt_require(crtc_output_combo_valid(data, crtc));
@@ -752,14 +763,22 @@ static void
 	/*
-	 * We assume an 8bits depth per color for degamma/gamma LUTs
+	 * We assume an 8bits or 10bits depth per color for degamma/gamma LUTs
 	 * for CRC checks with framebuffer references.
 	 */
-- 
2.46.0


^ permalink raw reply related	[flat|nested] 3+ messages in thread

end of thread, other threads:[~2026-04-13  7:30 UTC | newest]

Thread overview: 3+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2026-04-13  1:41 [PATCH i-g-t v2 1/1] tests/kms_color: Add 10-bit color depth support to gamma test for MediaTek Jay Liu
2026-04-13  6:50 ` Jani Nikula
2026-04-13  7:30   ` Jay Liu (刘博)

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox